Function winmsg_executor::spawn

source ·
pub fn spawn<F>(future: F) -> JoinHandle<F>
where F: Future + 'static, F::Output: 'static,
Spawns a new future on the current thread.

This function may be used to spawn tasks when the message loop is not running. The provided future will start running once the message loop is entered with [MessageLoop::block_on()] or [MessageLoop::run()].