Function winmsg_executor::block_on
source · pub fn block_on<F>(future: F) -> Result<F::Output, QuitMessageLoop>Expand description
Runs a future to completion on the calling threads message loop.
This runs the provided future on the current thread, blocking until it is complete. Any tasks spawned which the future spawns internally will be executed no the same thread.
Any spawned tasks will be suspended after block_on returns. Calling
block_on again will resume previously spawned tasks.
Panics
Panics when the message loops is running already. This happens when
block_on or run is called from async tasks running on this executor.