pub fn run_message_loop_with_dispatcher(dispatcher: impl Fn(&MSG) -> bool)Expand description
Runs the message loop, calling dispatcher for each received message.
If dispatcher has handled the message it shall return true. When returning
false the message it forwarded to the default dispatcher.
When using backend-async-task the message 0xB43A (WM_APP + 13370) is
reserved. Messages with that number will be handled and filtered by the
executor backend.
Executes previously spawned tasks.
Panics
Panics when the message loops is running already. This happens when
block_on or run is called from async tasks running on this executor.